@@ -49,7 +49,8 @@ import           Control.Applicative      ((<|>))
 import           Control.Category         ((>>>))
 import           Control.Exc              (orException, printingException)
 import           Lens.Micro.Platform      (makeLenses, use, (%~), (&), (.=), (.~), (^.))
-import           Control.Monad.Reader     (asks, foldM, unless, void, when)
+import           Control.Monad            (foldM, unless, void, when)
+import           Control.Monad.Reader     (asks)
 import qualified Data.Attoparsec.Text     as P
 import           Data.Binary              (Binary)
 import           Data.Char                (toLower)
@@ -89,11 +90,17 @@ import           System.PosixCompat.Files (FileStatus, fileExist, fileGroup,
                                            readSymbolicLink, removeLink, rename,
                                            unionFileModes)
 import           System.PosixCompat.Types (FileMode, GroupID, UserID)
-import           System.PosixCompat.User  (GroupEntry, GroupEntry (..),
-                                           UserEntry (..), getAllGroupEntries,
+#ifndef mingw32_HOST_OS
+#if MIN_VERSION_unix(2,8,0)
+import           System.Posix.User.ByteString (GroupEntry(GroupEntry), UserEntry(UserEntry))
+import           System.Posix.User        (getAllGroupEntries,
+#else
+import           System.Posix.User        (GroupEntry(..), UserEntry(..),getAllGroupEntries,
+#endif
                                            getAllUserEntries,
                                            getGroupEntryForID,
-                                           getUserEntryForID, groupID, userID)
+                                           getUserEntryForID, groupID, userID, userName, groupName)
+#endif
 import           Text.Printf              (printf)
 import           Yi.Buffer
 import           Yi.Config                (modeTable)
@@ -414,11 +421,11 @@ procDiredOp _ _ = return ()
 -- showNothing
 --
 -- 2. Confirmation is required for recursive deletion of non-empty
--- directry, but only the top level one
+-- directory, but only the top level one
 --
--- 3. Show the number of successful deletions at the end of the excution
+-- 3. Show the number of successful deletions at the end of the execution
 --
--- 4. TODO: ask confirmation for wether to remove the associated
+-- 4. TODO: ask confirmation for whether to remove the associated
 -- buffers when a file is removed
 askDelFiles :: FilePath -> [(FilePath, DiredEntry)] -> YiM ()
 askDelFiles dir fs =
@@ -665,6 +672,7 @@ diredScanDir dir = do
                 -> DiredEntries
                 -> FilePath
                 -> IO DiredEntries
+#ifndef mingw32_HOST_OS
     lineForFile d m f = do
       let fp = d </> f
       fileStatus <- getSymbolicLinkStatus fp
@@ -709,7 +717,6 @@ diredScanDir dir = do
                            , sizeInBytes = sz
                            , modificationTimeString = modTimeStr}
 
-
 -- | Needed on Mac OS X 10.4
 scanForUid :: UserID -> [UserEntry] -> UserEntry
 scanForUid uid entries = fromMaybe missingEntry $
@@ -724,6 +731,10 @@ scanForGid gid entries = fromMaybe missingEntry $
   where
     missingEntry = GroupEntry "?" mempty gid mempty
 
+#else
+    -- has been the default for Windows anyway, so just directly do it without unix-compat
+    lineForFile _ m f = return $ M.insert (R.fromString f) DiredNoInfo m
+#endif
 
 modeString :: FileMode -> R.YiString
 modeString fm = ""
@@ -1081,7 +1092,7 @@ diredCreateDir =
 
 -- | Elementary operations for dired file operations
 -- Map a dired mark operation (e.g. delete, rename, copy) command
--- into a list of DiredOps, and use procDiredOp to excute them.
+-- into a list of DiredOps, and use procDiredOp to execute them.
 -- Logic and implementation of each operation are packaged in procDiredOp
 -- See askDelFiles for example.
 -- If new elem op is added, just add corresponding procDiredOp to handle it.
