@@ -104,9 +104,8 @@ import           Prelude                        hiding (all, concatMap, foldl, f
 import           Lens.Micro.Platform            (Lens', lens, mapped,
                                                  use, view, (%=), (%~),
                                                  (&), (.~), (^.))
-import           Control.Monad                  (forM_, liftM)
-import           Control.Monad.Reader           (MonadReader (ask), asks,
-                                                 unless, when)
+import           Control.Monad                  (forM_, liftM, unless, when)
+import           Control.Monad.Reader           (MonadReader (ask), asks)
 import           Control.Monad.State            (gets, modify)
 import           Data.Binary                    (Binary, get, put)
 import           Data.Default                   (Default, def)
@@ -459,7 +458,7 @@ getRegE = uses killringA krGet
 -- | Dynamically-extensible state components.
 --
 -- These hooks are used by keymaps to store values that result from
--- Actions (i.e. that restult from IO), as opposed to the pure values
+-- Actions (i.e. that result from IO), as opposed to the pure values
 -- they generate themselves, and can be stored internally.
 --
 -- The `dynamic' field is a type-indexed map.
